@@ -59,11 +59,12 @@ $EXPORT_TAGS{'all'} = [];
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Carp qw/carp croak verbose/;
 use Data::Dumper;
 use IO::Scalar;
+use Term::ANSIColor qw(:constants);
 
 use D64::Disk::Dir::Entry;
 use D64::Disk::Image qw(:all);
@@ -213,7 +214,6 @@ sub _get_dir_info {
     # Get title and ID:
     my ($title, $id) = $d64DiskImageObj->title();
     $title = D64::Disk::Image->name_from_rawname($title);
-    $id = D64::Disk::Image->name_from_rawname($id);
     # Store directory details in a hash:
     $self->{'DIR_INFO'} = {
         'TITLE'       => $title,
@@ -266,7 +266,7 @@ sub get_title {
 
 =head2 get_id
 
-Get 2 character disk directory ID (PETSCII string):
+Get 5 character disk directory ID (PETSCII string):
 
   my $convert2ascii = 0;
   my $diskID = $d64DiskDirObj->get_id($convert2ascii);
@@ -363,6 +363,22 @@ sub get_file_data {
         return undef;
     }
     my $d64DiskImageObj = $self->{'D64_DISK_IMAGE'};
+
+    # Validate initial track/sector:
+    my $track = $entryObj->get_track();
+    my $sector = $entryObj->get_sector();
+    my $imageType = $d64DiskImageObj->type();
+    my $tracks = $d64DiskImageObj->tracks($imageType);
+    if ($track < 1 || $track > $tracks) {
+        carp "Unable to get file data from an illegal track (validate first that initial track ${track} really exists on this disk!)";
+        return undef;
+    }
+    my $sectors_per_track = $d64DiskImageObj->sectors_per_track($imageType, $track);
+    if ($sector < 0 || $sector >= $sectors_per_track) {
+        carp "Unable to get file data from an illegal sector (validate first that initial sector ${sector} really exists on track ${track}!)";
+        return undef;
+    }
+
     # Get filename from the specified directory index position:
     my $name = $entryObj->get_name(0);
     my $rawname = D64::Disk::Image->rawname_from_name($name);
@@ -406,10 +422,15 @@ sub print_dir {
           my $filetype = $file_type_constants{$type};
           # Read the file data only for PRG files:
           if ($filetype == T_PRG) {
-            # Compute the loading address:
-            my $data = $self->get_file_data($i);
-            my ($lo, $hi) = map { ord } split //, substr $data, 0, 2;
-            $loading_address = sprintf ' $%04x', $lo + $hi * 256;
+            # Do not attempt to read loading address of a non-closed file:
+            if ($entryObj->get_closed()) {
+              # Compute the loading address:
+              my $data = $self->get_file_data($i);
+              if ($data) {
+                my ($lo, $hi) = map { ord } split //, substr $data, 0, 2;
+                $loading_address = sprintf ' $%04x', $lo + $hi * 256;
+              }
+            }
           }
         }
         my $print_fh = new IO::Scalar;
@@ -432,7 +453,10 @@ sub _print_title {
     # Get disk ID converted to ASCII:
     my $id = $self->get_id(1);
     # Print title and disk ID:
-    printf $fh "0 \"%-16s\" %s\n", $title, $id;
+    print $fh '0 ';
+    my $header_text = sprintf "\"%-16s\" %-5s", $title, $id;
+    print $fh REVERSE, $header_text, RESET;
+    print $fh "\n";
 }
 
 sub _print_blocks_free {
@@ -474,7 +498,7 @@ Pawel Krol, E<lt>pawelkrol@cpan.orgE<gt>.
 
 =head1 VERSION
 
-Version 0.05 (2023-05-12)
+Version 0.06 (2023-08-28)
 
 =head1 COPYRIGHT AND LICENSE
 
