@@ -35,11 +35,13 @@ use bytes;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Carp qw/carp croak verbose/;
+use Data::Dumper;
 
 use D64::Disk::Image qw(:all);
+use D64::Disk::Dir;
 
 # File type names:
 our @file_types = qw/del seq prg usr rel cbm dir ???/;
@@ -190,6 +192,24 @@ sub get_type {
     return $file_type;
 }
 
+=head2 set_type
+
+Set the actual filetype:
+
+  my $type = T_DEL;
+  $entryObj->set_type($type);
+
+Sets the actual filetype as a symbollic type name, the possibilities here are: C<T_DEL>, C<T_SEQ>, C<T_PRG>, C<T_USR>, C<T_REL>, C<T_CBM>, and C<T_DIR>.
+
+=cut
+
+sub set_type {
+    my ($self, $type) = @_;
+    croak "An illegal file type: ${type}" unless grep { $type == $_ } values %D64::Disk::Dir::file_type_constants;
+    $self->{'DETAILS'}->{'TYPE'} = $type;
+    return $type;
+}
+
 =head2 get_closed
 
 Get "Closed" flag (when not set produces "*", or "splat" files):
@@ -206,6 +226,25 @@ sub get_closed {
     return $closed ? 1 : 0;
 }
 
+=head2 set_closed
+
+Set "Closed" flag:
+
+  $entryObj->set_closed(1);
+
+Clear "Closed" flag:
+
+  $entryObj->set_closed(0);
+
+=cut
+
+sub set_closed {
+    my ($self, $closed) = @_;
+    croak "An illegal closed flag: ${closed}" unless $closed == 0 || $closed == 1;
+    $self->{'DETAILS'}->{'CLOSED'} = $closed;
+    return $closed;
+}
+
 =head2 get_locked
 
 Get "Locked" flag (when set produces ">" locked files):
@@ -236,6 +275,20 @@ sub get_track {
     return $track;
 }
 
+=head2 set_track
+
+Set track location of first sector of file:
+
+  $entryObj->get_track($track);
+
+=cut
+
+sub set_track {
+    my ($self, $track) = @_;
+    $self->{'DETAILS'}->{'TRACK'} = $track;
+    return $track;
+}
+
 =head2 get_sector
 
 Get sector location of first sector of file:
@@ -250,6 +303,20 @@ sub get_sector {
     return $sector;
 }
 
+=head2 set_sector
+
+Set sector location of first sector of file:
+
+  $entryObj->set_sector($sector);
+
+=cut
+
+sub set_sector {
+    my ($self, $sector) = @_;
+    $self->{'DETAILS'}->{'SECTOR'} = $sector;
+    return $sector;
+}
+
 =head2 get_name
 
 Get 16 character filename (in PETASCII, padded with $A0):
@@ -416,7 +483,7 @@ Pawel Krol, E<lt>pawelkrol@cpan.orgE<gt>.
 
 =head1 VERSION
 
-Version 0.05 (2023-05-12)
+Version 0.06 (2023-08-28)
 
 =head1 COPYRIGHT AND LICENSE
 
